@@ -188,7 +188,7 @@ import sys
 from mako.lookup import TemplateLookup
 from mako.exceptions import TopLevelLookupException
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 """
 The current version of pdoc. This value is read from `setup.py`.
 """
@@ -1062,7 +1062,7 @@ class Function (Doc):
             else:
                 return '(%s)' % (', '.join(map(fmt_param, el)))
         try:
-            getspec = getattr(inspect, 'getfullargspec', 'getargspec')
+            getspec = getattr(inspect, 'getfullargspec', inspect.getargspec)
             s = getspec(self.func)
         except TypeError:
             # I guess this is for C builtin functions?
